@@ -268,8 +268,8 @@ class MyForm(QtGui.QMainWindow):
              QMessageBox.about(self, "About - SMSCON Editor", msg)
 
         def doCredits(self):
-             msg += unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
-             msg = "Control and Track your N900 through SMS\n\n"
+             msg = unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
+             msg += "Control and Track your N900 through SMS\n\n"
              msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas (saturn)\n"
              msg += "Configuration and Test User Interface for the SMSCON daemon\n\n"
              msg += "Distributed under GPL ver. 2"
